# stay on 1.35.x LTS until 1.39.x
# https://www.mediawiki.org/wiki/Version_lifecycle
%define basever 1.35
%define subver 1
%global __requires_exclude pear\\((extensions/.*|core/includes/WebStart.php|phase3/includes/WebStart.php|PHPUnit/Framework.php|src/hotp.php)\\)|/usr/bin/hhvm

Name:		mediawiki
Version:	%{basever}.%{subver}
Release:	%mkrel 2
Summary:	A wiki engine
License:	GPLv2+
Group:		System/Servers
BuildArch:	noarch
Url:		http://www.mediawiki.org/wiki/MediaWiki

Source0:	http://releases.wikimedia.org/mediawiki/%{basever}/%{name}-%{version}.tar.gz
Source1:	mediawiki.conf
# Save sqlite db in mediawiki data dir
Patch0:		mediawiki-1.35.0-sqlite-db-dir-fix.patch

# to make sure the "apache" group is created before mediawiki is installed
Requires(pre):	webserver-base
Requires:	webserver-base
# suggest apache-mod_php
Recommends:	apache-mod_php
# for diff3:
Requires:	diffutils
# for convert:
Requires:	imagemagick
Requires(post):	php-cli
Requires:	php-fileinfo
Requires:	php-gd
Requires:	php-iconv
Requires:	php-mbstring
Requires:	%{name}-sql = %{version}-%{release}
Requires:	php-xml
Recommends:	php-apcu
Recommends:	php-intl
Obsoletes:	php-oojs-oojs-ui < 0.41.0-2

%description
MediaWiki is the software used for Wikipedia and the other Wikimedia
Foundation websites. Compared to other wikis, it has an excellent
range of features and support for high-traffic websites using multiple
servers

This package includes math rendering support for mediawiki.

%package	mysql
Summary:	Mediawiki with mysql database
Group:		System/Servers
Provides:	%{name}-sql = %{version}-%{release}
Requires:	php-mysql

%description	mysql
This meta package installs the neccessary packages to use mediawiki
with a mariadb or mysql database.
This does not install the database server itself, because you can run
mediawiki with a remote database server.

%package	pgsql
Summary:	Mediawiki with postgresql database
Group:		System/Servers
Provides:	%{name}-sql = %{version}-%{release}
Requires:	php-pgsql

%description	pgsql
This meta package installs the neccessary packages to use mediawiki
with a postgresql database.
This does not install the database server itself, because you can run
mediawiki with a remote database server.

%package	sqlite
Summary:	Mediawiki with sqlite database
Group:		System/Servers
Provides:	%{name}-sql = %{version}-%{release}
Requires:	php-sqlite3
Requires:	php-pdo_sqlite

%description	sqlite
This meta package installs the neccessary packages to use mediawiki
with an sqlite database.
If you are using sqlite you can't use a remote database server.

%prep
%setup -q
%autopatch -p1

%build
# Fix shebangs
perl -pi -e 's|#!/usr/bin/env python|#!/usr/bin/env python3|' maintenance/language/zhtable/Makefile.py
perl -pi -e 's|\@prefix\@/bin/php|/usr/bin/php|' vendor/pear/mail_mime/scripts/phail.php 

%install
# Remove extension as it ships a bundled lua binary
rm -rf extensions/Scribunto

# now copy the rest to the buildroot.
mkdir -p %{buildroot}%{_datadir}/mediawiki
cp -a * %{buildroot}%{_datadir}/mediawiki/

# remove documentation
rm -f %{buildroot}%{_datadir}/mediawiki/{COPYING,FAQ,HISTORY,README,README.mediawiki,RELEASE-NOTES-%{basever},UPGRADE,CREDITS,INSTALL}
rm -rf %{buildroot}%{_datadir}/mediawiki/docs

# remove unneeded parts
rm -fr %{buildroot}%{_datadir}/mediawiki/{t,test,tests}
find %{buildroot}%{_datadir}/mediawiki/ -name .htaccess -exec rm -f {} +

# fix permissions
find %{buildroot}%{_datadir}/mediawiki -name \*.pl -exec chmod +x {} +

# remove version control/patch files
find %{buildroot} -name .git\* -exec rm -f {} +

%{__install} -d -m 755 %{buildroot}%{webappconfdir}
install -p -m 0644 %{SOURCE1} \
  %{buildroot}%{webappconfdir}/mediawiki.conf

mkdir %{buildroot}%{_sysconfdir}/mediawiki

# placeholder for a default instance
mkdir -p %{buildroot}/%{_localstatedir}/www/mediawiki

# move editable things out of /usr
mv %{buildroot}%{_datadir}/mediawiki/images %{buildroot}%{_localstatedir}/www/mediawiki/images
ln -s %{_sysconfdir}/mediawiki/LocalSettings.php %{buildroot}%{_datadir}/mediawiki/LocalSettings.php

install -d -m 755 %{buildroot}/%{_localstatedir}/lib/mediawiki

%post
php %{_datadir}/mediawiki/maintenance/update.php --quick > /dev/null
if [ ! -e %{_datadir}/mediawiki/images ]; then
    ln -s %{_localstatedir}/www/mediawiki/images %{_datadir}/mediawiki/images
fi

%files
%doc COPYING FAQ HISTORY README.md RELEASE-NOTES-%{basever} UPGRADE CREDITS INSTALL docs
%{_datadir}/mediawiki
%config(noreplace) %{webappconfdir}/mediawiki.conf
%dir %{_sysconfdir}/mediawiki
%dir %{_localstatedir}/www/mediawiki
%attr(-,apache,apache) %dir %{_localstatedir}/www/mediawiki/images
%attr(-,apache,apache) %{_localstatedir}/www/mediawiki/images/README

%files mysql

%files pgsql

%files sqlite
%attr(-,apache,apache) %{_localstatedir}/lib/mediawiki


%changelog
* Sun Dec 27 2020 luigiwalser <luigiwalser> 1.35.1-2.mga8
+ Revision: 1664048
- obsolete php-oojs-oojs-ui, not unbundled and only used in mediawiki

* Fri Dec 18 2020 luigiwalser <luigiwalser> 1.35.1-1.mga8
+ Revision: 1660963
- 1.35.1

* Fri Dec 04 2020 luigiwalser <luigiwalser> 1.35.0-2.mga8
+ Revision: 1652659
- fix bogus pear dep

* Thu Dec 03 2020 luigiwalser <luigiwalser> 1.35.0-1.mga8
+ Revision: 1652215
- 1.35.0
- rediff patch 0
- remove extension that bundles lua binary

* Sat Sep 26 2020 luigiwalser <luigiwalser> 1.31.10-1.mga8
+ Revision: 1630650
- 1.31.10

* Wed Jul 08 2020 luigiwalser <luigiwalser> 1.31.8-1.mga8
+ Revision: 1602890
- 1.31.8

* Mon Apr 06 2020 luigiwalser <luigiwalser> 1.31.7-1.mga8
+ Revision: 1565338
- 1.31.7
- mw-config should not be owned by apache

* Tue Feb 18 2020 umeabot <umeabot> 1.31.6-2.mga8
+ Revision: 1541544
- Mageia 8 Mass Rebuild

* Sun Dec 29 2019 luigiwalser <luigiwalser> 1.31.6-1.mga8
+ Revision: 1474658
- 1.31.6

* Wed Oct 16 2019 tmb <tmb> 1.31.5-1.mga8
+ Revision: 1454181
- update to 1.31.5

* Mon Oct 14 2019 luigiwalser <luigiwalser> 1.31.4-1.mga8
+ Revision: 1453123
- 1.31.4

* Mon Aug 12 2019 luigiwalser <luigiwalser> 1.31.3-1.mga8
+ Revision: 1428850
- 1.31.3

* Fri Feb 15 2019 luigiwalser <luigiwalser> 1.31.1-2.mga7
+ Revision: 1367320
- add missing dep php-fileinfo (mga#24364)

* Thu Oct 25 2018 bcornec <bcornec> 1.31.1-1.mga7
+ Revision: 1325480
- update to upstream 1.31.1 to fix mga#23662

* Thu Sep 20 2018 umeabot <umeabot> 1.27.4-2.mga7
+ Revision: 1279502
- Mageia 7 Mass Rebuild

* Thu Nov 16 2017 shlomif <shlomif> 1.27.4-1.mga7
+ Revision: 1177529
- New version 1.27.4 (thanks to kekePower; with fixes)

* Fri Jul 07 2017 luigiwalser <luigiwalser> 1.27.3-2.mga6
+ Revision: 1109376
- requires php-mbstring

* Wed May 10 2017 luigiwalser <luigiwalser> 1.27.3-1.mga6
+ Revision: 1099946
- 1.27.3

* Tue Apr 11 2017 akien <akien> 1.27.2-1.mga6
+ Revision: 1096352
- Version 1.27.2 (many CVE fixes)

* Sat Dec 10 2016 ngompa <ngompa> 1.27.1-2.mga6
+ Revision: 1074079
- Remove unneeded %%pretrans

* Fri Aug 26 2016 luigiwalser <luigiwalser> 1.27.1-1.mga6
+ Revision: 1049111
- 1.27.1

* Wed Jul 06 2016 tmb <tmb> 1.27.0-1.mga6
+ Revision: 1039165
- rebase P0
- drop P1 (merged)
+ luigiwalser <luigiwalser>
- 1.27.0
- require php-iconv and recommend php-apcu as mw-config does (buchan)

* Mon May 23 2016 luigiwalser <luigiwalser> 1.23.14-1.mga6
+ Revision: 1017941
- 1.23.14

* Sun Feb 21 2016 tmb <tmb> 1.23.13-1.mga6
+ Revision: 975279
- 1.23.13: (T121892) Fix fatal errors on some Special pages, introduced in 1.23.12.
+ luigiwalser <luigiwalser>
- apply some apache settings to images dir to file upload security (buchan)

* Mon Dec 21 2015 luigiwalser <luigiwalser> 1.23.12-1.mga6
+ Revision: 913242
- 1.23.12

* Tue Oct 20 2015 luigiwalser <luigiwalser> 1.23.11-1.mga6
+ Revision: 893009
- 1.23.11

* Fri Aug 28 2015 luigiwalser <luigiwalser> 1.23.10-2.mga6
+ Revision: 870710
- add /usr/bin/hhvm to exclusions for automatic requirements

* Wed Aug 12 2015 luigiwalser <luigiwalser> 1.23.10-1.mga6
+ Revision: 863625
- 1.23.10

* Wed Apr 01 2015 luigiwalser <luigiwalser> 1.23.9-1.mga5
+ Revision: 819489
- 1.23.9

* Sun Dec 21 2014 luigiwalser <luigiwalser> 1.23.8-1.mga5
+ Revision: 804611
- 1.23.8

* Tue Dec 02 2014 luigiwalser <luigiwalser> 1.23.7-1.mga5
+ Revision: 800292
- 1.23.7

* Wed Oct 29 2014 luigiwalser <luigiwalser> 1.23.6-1.mga5
+ Revision: 794610
- 1.23.6

* Thu Oct 23 2014 luigiwalser <luigiwalser> 1.23.5-5.mga5
+ Revision: 792712
- do not create backup files when patching

* Thu Oct 23 2014 luigiwalser <luigiwalser> 1.23.5-4.mga5
+ Revision: 792565
- patch out wikimedia-specific code that causes autoreq deps problem

* Wed Oct 15 2014 umeabot <umeabot> 1.23.5-3.mga5
+ Revision: 742738
- Second Mageia 5 Mass Rebuild

* Fri Oct 03 2014 diogenese <diogenese> 1.23.5-2.mga5
+ Revision: 736412
- Store sqlite database in mediawiki var directory

* Thu Oct 02 2014 luigiwalser <luigiwalser> 1.23.5-1.mga5
+ Revision: 734704
- 1.23.5

* Wed Oct 01 2014 tv <tv> 1.23.4-2.mga5
+ Revision: 733992
- rebuild for pear deps

* Fri Sep 26 2014 luigiwalser <luigiwalser> 1.23.4-1.mga5
+ Revision: 725435
- 1.23.4

* Tue Sep 16 2014 umeabot <umeabot> 1.23.3-2.mga5
+ Revision: 682335
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes
- s/uggests:/Recommends:/

* Thu Aug 28 2014 luigiwalser <luigiwalser> 1.23.3-1.mga5
+ Revision: 669146
- 1.23.3

* Thu Jul 31 2014 luigiwalser <luigiwalser> 1.23.2-1.mga5
+ Revision: 658768
- 1.23.2

* Thu Jun 26 2014 luigiwalser <luigiwalser> 1.23.1-1.mga5
+ Revision: 639930
- 1.23.1

* Thu Jun 05 2014 tmb <tmb> 1.23.0-1.mga5
+ Revision: 633562
- update to 1.23 (LTS)

* Tue Jun 03 2014 luigiwalser <luigiwalser> 1.22.7-1.mga5
+ Revision: 632599
- 1.22.7

* Sat Apr 26 2014 luigiwalser <luigiwalser> 1.22.6-1.mga5
+ Revision: 618271
- 1.22.6

* Fri Mar 28 2014 luigiwalser <luigiwalser> 1.22.5-1.mga5
+ Revision: 609054
- 1.22.5

* Sat Mar 15 2014 luigiwalser <luigiwalser> 1.22.4-1.mga5
+ Revision: 604013
- 1.22.4

* Tue Mar 04 2014 luigiwalser <luigiwalser> 1.22.3-1.mga5
+ Revision: 599475
- 1.22.3
- update source URL

* Wed Feb 26 2014 luigiwalser <luigiwalser> 1.22.2-3.mga5
+ Revision: 597405
- obsolete unmaintained, insecure graphviz extension

* Wed Feb 26 2014 luigiwalser <luigiwalser> 1.22.2-2.mga5
+ Revision: 597404
- remove broken, undocumented instances feature
- run db schema upgrade maintenance script in post scriplet

* Thu Feb 06 2014 luigiwalser <luigiwalser> 1.22.2-1.mga5
+ Revision: 584845
- 1.22.2
- cosmetic fixes in spec file
- require php-pdo_sqlite for mediawiki-sqlite (from diogenese)

* Mon Dec 02 2013 luigiwalser <luigiwalser> 1.20.8-1.mga4
+ Revision: 554660
- 1.20.8

* Sat Oct 19 2013 umeabot <umeabot> 1.20.7-2.mga4
+ Revision: 533771
- Mageia 4 Mass Rebuild

* Wed Sep 04 2013 luigiwalser <luigiwalser> 1.20.7-1.mga4
+ Revision: 475117
- 1.20.7

* Thu Jul 18 2013 luigiwalser <luigiwalser> 1.20.6-3.mga4
+ Revision: 455979
- obsolete bundled renameuser mediawiki extension

* Wed Jul 17 2013 luigiwalser <luigiwalser> 1.20.6-2.mga4
+ Revision: 455129
- allow access to wiki but restrict access to installer
- fix setting conflict with suhosin
- only require webserver-base for apache user
- suggest php-intl to speed up unicode
- move LocalSettings.php to /etc/mediawiki
- move "images" file upload directory to /var/www/mediawiki

* Thu May 23 2013 kharec <kharec> 1.20.6-1.mga4
+ Revision: 425149
- update to 1.20.6

* Sat May 04 2013 kharec <kharec> 1.20.5-1.mga3
+ Revision: 412242
- New security release 1.20.5 (#3448)

* Thu Apr 18 2013 kharec <kharec> 1.20.4-1.mga3
+ Revision: 410429
- Security release 1.20.4

* Sat Apr 13 2013 guillomovitch <guillomovitch> 1.20.3-1.mga3
+ Revision: 409877
- drop references to non existing README.urpmi in package description
- ship a single apache configuration file, providing a simple setup working ouf of the box (#7443)
- ship /var/lib/mediawiki as database container in mediawiki-sqlite
- fix documentation file installation directory
- cleanup spec file
+ kharec <kharec>
- New version 1.20.3
- Clean package

* Sat Jan 12 2013 umeabot <umeabot> 1.19.2-3.mga3
+ Revision: 359904
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 08 2012 guillomovitch <guillomovitch> 1.19.2-2.mga3
+ Revision: 290498
- make configuration file compatible with apache 2.4
- make default configuration file compliant with setup
+ obgr_seneca <obgr_seneca>
- fixed README.urpmi

* Sat Sep 08 2012 obgr_seneca <obgr_seneca> 1.19.2-1.mga3
+ Revision: 290105
- new version 1.19.2
- reworked instance creation script

* Tue Jul 10 2012 obgr_seneca <obgr_seneca> 1.19.1-1.mga3
+ Revision: 269190
- New version 1.19.1
- main package now named mediawiki, not mediawiki-minimal
- math package now in an external extension (upstream change)
- added database meta packages for mysql, postgresql and sqlite

* Sat Nov 19 2011 spuhler <spuhler> 1.16.5-3.mga2
+ Revision: 169372
- added pear(extensions\\|pear(PHPUnit/Framework.php) to define _requires_exceptions
  dropped pear(HTML/Template/PHPTAL.php)\\|pear(MogileFS.php) from define _requires_exceptions as it isn't required anymore

* Thu Jun 23 2011 cjw <cjw> 1.16.5-2.mga2
+ Revision: 112830
- fix create script reference in update script

* Sun May 15 2011 boklm <boklm> 1.16.5-1.mga1
+ Revision: 98859
- update to version 1.16.4 (security release)
- remove apache-mod_php dependency as it could be used with other web servers, or without mod_php
- add default config file
+ cjw <cjw>
- add note about upgrading in README.RPM
- rebase on mediawiki package in fedora:
  o split code from configuration/userdata
  o allow multiple wiki instances
  o allow installations without tex
- rename nomath package to mediawiki-minimal
- rename math package to mediawiki
- 1.16.5 security release
- fix patch0 to support wiki installs using a postgresql database
- rename mw-createinstance to mediawiki-create and
  mw-updateallinstances to mediawiki-updateall
- fix filelist by listing all files and dirs in the shared code dir

* Mon Mar 21 2011 boklm <boklm> 1.16.2-4.mga1
+ Revision: 75276
- add provide on base version
- install mediawiki in /usr/share/mediawiki and config in /etc/mediawiki
- update summary and description
- remove all plugins
- imported package mediawiki


* Tue Mar 15 2011 Nicolas Vigier <boklm@mars-attacks.org> 1.16.2-4
- rename package to mediawiki

* Thu Mar 03 2011 Oliver Burger <rpm@mandrivauser.de> 1.16.2-3mud2010.2
- added README.urpmi

* Wed Mar 02 2011 Oliver Burger <rpm@mandrivauser.de> 1.16.2-2mud2010.2
- added RenameUser extension needed by ldap extension

* Wed Mar 02 2011 Oliver Burger <rpm@mandrivauser.de> 1.16.2-1mud2010.2
- added ldap extension to mageia-multilingual
- split multilinugual setup from main rpm

* Sun Feb 13 2011 Oliver Burger <rpm@mandrivauser.de> 1.16.1-2mud2010.2
- changed paths for multilingual setup

* Thu Jan 06 2011 Oliver Burger <rpm@mandrivauser.de> 1.16.1-1mud2010.2
- new version 1.16.1

* Thu Nov 18 2010 Oliver Burger <rpm@mandrivauser.de> 1.15.1-1mud2010.1
- rebuild for 2010.1

* Wed Aug 12 2009 Thierry Vignaud <tvignaud@mandriva.com> 1.15.1-1mdv2010.0
+ Revision: 415375
- new release

* Fri Jan 23 2009 Jérôme Soyer <saispo@mandriva.org> 1.13.3-1mdv2009.1
+ Revision: 332775
- New upstream release

  + Oden Eriksson <oeriksson@mandriva.com>
    - lowercase ImageMagick

* Tue Oct 28 2008 Buchan Milne <bgmilne@mandriva.org> 1.13.2-2mdv2009.1
+ Revision: 297946
- Fix bug #45201 (Files missing in mediawiki package, preventing use)

* Sat Oct 11 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.13.2-1mdv2009.1
+ Revision: 291674
- new release

* Fri Sep 12 2008 Frederik Himpe <fhimpe@mandriva.org> 1.13.1-1mdv2009.0
+ Revision: 284279
- update to new version 1.13.1

* Thu Aug 14 2008 Funda Wang <fundawang@mandriva.org> 1.13.0-1mdv2009.0
+ Revision: 272172
- New version 1.13.0

* Mon Jun 30 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.12.0-1mdv2009.0
+ Revision: 230340
- new release

* Mon Mar 03 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.11.2-1mdv2008.1
+ Revision: 178031
- new release

* Thu Feb 28 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.11.1-3mdv2008.1
+ Revision: 176228
- better summary
- new license policy
- do not package COPYING and INSTALL files
- spec file clean

* Wed Feb 27 2008 Christiaan Welvaart <spturtle@mandriva.org> 1.11.1-2mdv2008.1
+ Revision: 175925
- fix file uploads: add filerepo and media include dirs
  and make images dir writable by webserver

* Sun Feb 03 2008 Funda Wang <fundawang@mandriva.org> 1.11.1-1mdv2008.1
+ Revision: 161668
- update to new version 1.11.1

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request
    - fix downlod URL

* Tue Oct 09 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.11.0-1mdv2008.1
+ Revision: 96134
- new release

* Wed Sep 05 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.10.1-1mdv2008.0
+ Revision: 80180
- new release

* Wed May 16 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.10.0-2mdv2008.0
+ Revision: 27387
- do not require PHPUnit.php (not needed for normal use)

* Thu May 10 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.10.0-1mdv2008.0
+ Revision: 26080
- new release


* Mon Feb 26 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.9.3-1mdv2007.0
+ Revision: 125978
- new release

* Mon Feb 05 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.9.2-1mdv2007.1
+ Revision: 116244
- new release
- bump release
- add missing files

* Fri Jan 26 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.9.1-1mdv2007.1
+ Revision: 114008
- new release
- fix URL

* Wed Jan 10 2007 Thierry Vignaud <tvignaud@mandriva.com> 1.9.0-1mdv2007.1
+ Revision: 107274
- new release

* Mon Nov 27 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.8.2-2mdv2007.1
+ Revision: 87495
- bump release
- prevent requiring internal extensions, thus fixing installation

* Thu Nov 23 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.8.2-1mdv2007.1
+ Revision: 86836
- Import mediawiki

* Tue Oct 24 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.8.2-1mdv2007.1
- new release

* Sat Jul 29 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.7.1-2mdv2007.0
- some rpmlint fixes
- patch 0: fix looping on accessing installation wizard
- patch 1: fix installation if not using root access

* Sat Jul 29 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.7.1-2mdv2007.0
- fix requires

* Wed Jul 26 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.7.1-1mdv2007.0
- new release

* Fri Jun 30 2006 Jerome Martin <jmartin@mandriva.org> 1.6.7-3mdv2007.0
- Fix installed files
- Add http conf

* Fri Jun 30 2006 Jerome Martin <jmartin@mandriva.org> 1.6.7-2mdv2007.0
- Fix install dir to %%{_var}/www/

* Sun Jun 18 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.6.7-1mdv2007.0
- new release

* Thu Apr 20 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 1.6.3-1mdk
- 1.6.3

* Tue Mar 28 2006 Lenny Cartier <lenny@mandriva.com> 1.5.8-1mdk
- 1.5.8

* Tue Feb 28 2006 Jerome Soyer <saispo@mandriva.org> 1.5.6-1mdk
- New release 1.5.6

* Tue Nov 08 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 1.5.2-1mdk
- new version
- fix apache requires (Anne Nicolas)

* Sat Jun 18 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.4.5-3mdk
- requires php-gd

* Wed Jun 15 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.4.5-2mdk
- drop MySQL requires (#16277)

* Tue Jun 14 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.4.5-1mdk
- new release
- requires php-mysql

* Mon May 02 2005 Anne Nicolas <anne.nicolas@mandriva.com> 1.4.3-1mdk
- new version

* Wed Apr 27 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.4.2-3mdk
- mediawiki cannot work without php-xml
- fix config file ownership

* Tue Apr 26 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 1.4.2-2mdk
- Fix URL; misc spec cleanups

* Mon Apr 25 2005 Anne Nicolas <anne.nicolas@mandriva.com> 1.4.2-1mdk
- first mdk release

